@@ -307,7 +307,7 @@ combine (unsigned long a, unsigned long b, unsigned long *result)
 
   if (index_a >= COMPOSE_FIRST_START && index_a < COMPOSE_FIRST_SINGLE_START
       && index_b >= COMPOSE_SECOND_START
-      && index_a < COMPOSE_SECOND_SINGLE_START)
+      && index_b < COMPOSE_SECOND_SINGLE_START)
     {
       unsigned long res =
 	compose_array[index_a - COMPOSE_FIRST_START][index_b -
@@ -755,7 +755,7 @@ stringprep_utf8_nfkc_normalize (const char *str, ssize_t len)
  * @len: length of @str array, or -1 if @str is nul-terminated.
  *
  * Converts UCS4 string into UTF-8 and runs
- * stringprep_utf4_nfkc_normalize().
+ * stringprep_utf8_nfkc_normalize().
  *
  * Return value: a newly allocated Unicode string, that is the NFKC
  *   normalized form of @str.
